KeyPathValueTarget

Trait KeyPathValueTarget 

pub trait KeyPathValueTarget {
    type Target: Sized;
}
Used so async chaining can infer the referent of a reference-valued step (e.g. &T and &mut T both map to T).

Required Associated Types

type Target: Sized

The type pointed to when Self is a reference.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: Sized> KeyPathValueTarget for &T

Source

impl<T: Sized> KeyPathValueTarget for &mut T

Implementors